aboutsummaryrefslogtreecommitdiff
path: root/crypto-common/src
diff options
context:
space:
mode:
Diffstat (limited to 'crypto-common/src')
-rw-r--r--crypto-common/src/main/kotlin/dev/msfjarvis/aps/crypto/CryptoHandler.kt12
1 files changed, 6 insertions, 6 deletions
diff --git a/crypto-common/src/main/kotlin/dev/msfjarvis/aps/crypto/CryptoHandler.kt b/crypto-common/src/main/kotlin/dev/msfjarvis/aps/crypto/CryptoHandler.kt
index c64e9c9b..eb04ee7a 100644
--- a/crypto-common/src/main/kotlin/dev/msfjarvis/aps/crypto/CryptoHandler.kt
+++ b/crypto-common/src/main/kotlin/dev/msfjarvis/aps/crypto/CryptoHandler.kt
@@ -12,22 +12,22 @@ import java.io.OutputStream
public interface CryptoHandler {
/**
* Decrypt the given [ciphertextStream] using a [privateKey] and [password], and writes the
* resultant plaintext to [outputStream].
*/
public fun decrypt(
- privateKey: String,
- password: String,
+ privateKey: Key,
+ passphrase: String,
ciphertextStream: InputStream,
outputStream: OutputStream,
)
/**
- * Encrypt the given [plaintextStream] to the provided [pubKeys], and writes the encrypted
- * ciphertext to [outputStream].
+ * Encrypt the given [plaintextStream] to the provided [keys], and writes the encrypted ciphertext
+ * to [outputStream].
*/
public fun encrypt(
- pubKeys: List<String>,
+ keys: List<Key>,
plaintextStream: InputStream,
outputStream: OutputStream,
)
@@ -12,22 +12,22 @@ import java.io.OutputStream
public interface CryptoHandler {
/**
- * Decrypt the given [ciphertextStream] using a [privateKey] and [password], and writes the
+ * Decrypt the given [ciphertextStream] using a [privateKey] and [passphrase], and writes the
* resultant plaintext to [outputStream].
*/